pub(crate) struct LayoutContext<'a> {
pub style_context: SharedStyleContext<'a>,
pub font_context: Arc<FontContext>,
pub iframe_sizes: Mutex<IFrameSizes>,
pub image_resolver: Arc<ImageResolver>,
pub painter_id: PainterId,
pub allow_parallel_layout: bool,
pub parallelism_job_count_minimum: usize,
pub parallelism_job_size_minimum: usize,
}Fields
style_context: SharedStyleContext<'a>Bits shared by the layout and style system.
font_context: Arc<FontContext>A FontContext to be used during layout.
iframe_sizes: Mutex<IFrameSizes>A collection of <iframe> sizes to send back to script.
image_resolver: Arc<ImageResolver>An ImageResolver used for resolving images during box and fragment
tree construction. Later passed to display list construction.
painter_id: PainterIdThe PainterId that identifies which RenderingContext that this layout targets.
allow_parallel_layout: boolWhether or not parallel layout should be allowed for this layout.
parallelism_job_count_minimum: usizeThe minimum number of jobs that need to be larger than
Self::parallelism_job_size_minimum in order to enable parallelism.
parallelism_job_size_minimum: usizeThe minimum size a job needs to be to be counted when determining if the number of
jobs exceeds Self::parallelism_job_count_minimum.
Implementations
Sourceimpl LayoutContext<'_>
impl LayoutContext<'_>
pub(crate) fn should_parallelize(&self, number_of_jobs: usize) -> bool
pub(crate) fn should_parallelize_layout( &self, jobs: impl Iterator<Item = usize>, ) -> bool